helloworld-jmg
##############

A test


Quickstart
==========

helloworld-jmg is available on PyPI and can be installed with `pip <https://pip.pypa.io>`_.

.. code-block:: console

    $ pip install helloworld-jmg

After installing helloworld-jmg you can use it like any other Python module.

Here is a simple example:

.. code-block:: python

    import helloworld-jmg
    # Fill this section in with the common use-case.

The `API Reference <http://helloworld-jmg.readthedocs.io>`_ provides API-level documentation.
